import React, { useState } from "react";
import { useHistory } from "react-router-dom";

import { Container, BackButtonDiv, Image, TransparentButton } from "./styled";
import { GrView } from "react-icons/gr";
import { useAuth } from "../../contexts/auth";

import JobQuestLogin from "../../assets/images/JobQuestLogin.png";
import BackButton from "../../components/BackButton";
import ButtonWithIcon from "../../components/ButtonWithIcon";
import InputForm from "../../containers/InputForm";
import redirectByProfile from "../../utility/redirectByProfile";

function Login() {
  const [mail, setMail] = useState("");
  const [password, setPassword] = useState("");
  const [type, setType] = useState("password");
  const [error, setError] = useState(false);
  const history = useHistory();
  const { signIn } = useAuth();

  async function handleLogin() {
    try {
      const response = await signIn(mail, password);
      redirectByProfile(response.userData.tipo_usuario, history);
    } catch (error) {
      setError(true);
    }
  }

  return (
    <Container>
      <BackButtonDiv>
        <BackButton route="/" />
      </BackButtonDiv>

      <Image src={JobQuestLogin} />

      {error && <h4>Erro de autenticação, verifique e tente novamente!</h4>}

      <InputForm text="E-mail" change={setMail} />
      <InputForm
        text="Senha"
        icon={<GrView />}
        type={type}
        setType={setType}
        change={setPassword}
      />

      <TransparentButton align="right">Esqueci minha senha</TransparentButton>

      <ButtonWithIcon
        name={"entrar"}
        execFunction={handleLogin}
        marginTop={2}
        marginLeft={15}
      />

      <TransparentButton
        onClick={() => history.push("/registre-se")}
        align="center"
      >
        Não tenho cadastro
      </TransparentButton>
    </Container>
  );
}

export default Login;
