import axios from "axios";
import { strings } from "../assets/config";

/**
 * BASE URLS of the service used on VacancyService.
 */
const BASE_VACANCY = "vacancies/";

/**
 * URLS of the service used on VacancyService.
 */
const RESOURCES = {
  LIST_VACANCIES: BASE_VACANCY,
  GET_VACANCY: (vacancyId) => `${BASE_VACANCY}/${vacancyId}`,
};

/**
 * Params used on services methods.
 */
const PARAMS = {
  ID_EMPRESA: "id_empresa",
  ID_AREA: "id_area",
  TITULO: "nome",
  QUANTIDADE: "quantidade",
  DESCRICAO: "descricao",
  HABILIDADES: "habilidades",
};

class VacancyService {
  static async listVacancies() {
    try {
      return axios.get(RESOURCES.LIST_VACANCIES, {
        params: {
          tipo: "N",
        },
      });
    } catch (error) {
      console.log(error);
      return strings.errors.genericError;
    }
  }

  static async getVacancyById(vacancyId) {
    try {
      return axios.get(RESOURCES.GET_VACANCY(vacancyId));
    } catch (error) {
      console.log(error);
      return strings.errors.genericError;
    }
  }

  static async createVacancy(payload) {
    try {
      return axios.post(BASE_VACANCY, {
        [PARAMS.ID_EMPRESA]: payload.idEmpresa,
        [PARAMS.ID_AREA]: 1,
        [PARAMS.TITULO]: payload.role,
        [PARAMS.QUANTIDADE]: payload.quantity,
        [PARAMS.DESCRICAO]: payload.description,
        [PARAMS.HABILIDADES]: payload.skills,
      });
    } catch (error) {
      console.log(error);
      return strings.errors.genericError;
    }
  }
}

export default VacancyService;
